Package: CSTools
Title: Assessing Skill of Climate Forecasts on Seasonal-to-Decadal
        Timescales
Version: 5.3.2
Authors@R: c(
    person("Nuria", "Perez-Zanon", , "nuria.perez@bsc.es", role = "aut", comment = c(ORCID = "0000-0001-8568-3071")),
    person("Louis-Philippe", "Caron", , "louis-philippe.caron@bsc.es", role = "aut", comment = c(ORCID = "0000-0001-5221-0147")),
    person("Carmen", "Alvarez-Castro", , "carmen.alvarez-castro@cmcc.it", role = "aut", comment = c(ORCID = "0000-0002-9958-010X")),
    person("Lauriane", "Batte", , "lauriane.batte@meteo.fr", role = "aut"),
    person("Carlos", "Delgado", , "carlos.delgado@bsc.es", role = "aut"),
    person("Jost", "von Hardenberg", , email = c("j.vonhardenberg@isac.cnr.it", "jost.hardenberg@polito.it"), role = "aut",  comment = c(ORCID = "0000-0002-5312-8070")),
    person("Llorenç", "LLedo", , "llledo@bsc.es", role = "aut"), 
    person("Nicolau", "Manubens", , "nicolau.manubens@bsc.es", role = "aut"),
    person("Lluís", "Palma", , "lluis.palma@bsc.es", role = "aut"),
    person("Eroteida", "Sanchez-Garcia", , "esanchezg@aemet.es", role = "aut"),
    person("Bert", "van Schaeybroeck", , "bertvs@meteo.be", role = "aut"),
    person("Veronica", "Torralba", , "veronica.torralba@bsc.es", role = "aut"),
    person("Deborah", "Verfaillie", , "deborah.verfaillie@bsc.es", role = "aut"),
    person("Eva", "Rifà", , "eva.rifarovira@bsc.es", role = c("ctb")),
    person("Filippo", "Cali Quaglia", , "filippo.caliquaglia@gmail.com", role = "ctb"),
    person("Maria M.", "Chaves-Montero", , "mariadm.chaves@cmcc.it", role = "ctb"),
    person("Chihchung", "Chou", , "chihchung.chou@bsc.es", role = "ctb"),
    person("Nicola", "Cortesi", , "nicola.cortesi@bsc.es", role = "ctb"),
    person("Susanna", "Corti", , "s.corti@isac.cnr.it", role = "ctb"),
    person("Paolo", "Davini", , "p.davini@isac.cnr.it", role = "ctb"),
    person("Gildas", "Dayon", , "gildas.dayon@meteo.fr", role = "ctb"),
    person("Marta", "Dominguez", , "mdomingueza@aemet.es", role = "ctb"),
    person("Federico", "Fabiano", , "f.fabiano@isac.cnr.it", role = "ctb"),
    person("Ignazio", "Giuntoli", , "i.giuntoli@isac.cnr.it", role = "ctb"),
    person("Raul", "Marcos", , "raul.marcos@bsc.es", role = "ctb"),
    person("Paola", "Marson", , "paola.marson@meteo.fr", role = "ctb"),
    person("Niti", "Mishra", , "niti.mishra@bsc.es", role = "ctb"),
    person("Jesus", "Peña", , "jesus.pena@bsc.es", role = "ctb"),
    person("Francesc", "Roura-Adserias", , "francesc.roura@bsc.es", role = "ctb"),
    person("Silvia", "Terzago", , "s.terzago@isac.cnr.it", role = "ctb"),
    person("Danila", "Volpi", , "d.volpi@isac.cnr.it", role = "ctb"),
    person("An-Chi", "Ho", , "an.ho@bsc.es", role = "ctb"),
    person("Victoria", "Agudetse", , "victoria.agudetse@bsc.es", role = c("ctb", "cre")),
    person("Theertha", "Kariyathan", , "theertha.kariyathan@bsc.es", role = "ctb"),
    person("Eren", "Duzenli", , "eren.duzenli@bsc.es", role = "ctb"),
    person("BSC-CNS", role = c("cph")))
Description: Exploits dynamical seasonal forecasts in order to provide
    information relevant to stakeholders at the seasonal timescale. The package
    contains process-based methods for forecast calibration, bias correction,
    statistical and stochastic downscaling, optimal forecast combination and
    multivariate verification, as well as basic and advanced tools to obtain
    tailored products. This package was developed in the context of the ERA4CS 
    project MEDSCOPE and the H2020 S2S4E project and includes contributions from 
    ArticXchange project founded by EU-PolarNet 2. Implements methods described in
    Pérez-Zanón et al. (2022) <doi:10.5194/gmd-15-6115-2022>,
    Doblas-Reyes et al. (2005) <doi:10.1111/j.1600-0870.2005.00104.x>,
    Mishra et al. (2018) <doi:10.1007/s00382-018-4404-z>,
    Sanchez-Garcia et al. (2019) <doi:10.5194/asr-16-165-2019>,
    Straus et al. (2007) <doi:10.1175/JCLI4070.1>,
    Terzago et al. (2018) <doi:10.5194/nhess-18-2825-2018>,
    Torralba et al. (2017) <doi:10.1175/JAMC-D-16-0204.1>,
    D'Onofrio et al. (2014) <doi:10.1175/JHM-D-13-096.1>,
    Verfaillie et al. (2017) <doi:10.5194/gmd-10-4257-2017>,
    Van Schaeybroeck et al. (2019) <doi:10.1016/B978-0-12-812372-0.00010-8>,
    Yiou et al. (2013) <doi:10.1007/s00382-012-1626-3>.
Depends: R (>= 3.5.0), maps, qmap, easyVerification
Imports: s2dv, startR, rainfarmr, multiApply (>= 2.1.1), ClimProjDiags,
        ncdf4, plyr, abind, data.table, reshape2, ggplot2,
        RColorBrewer, graphics, grDevices, stats, utils, verification,
        lubridate, scales, easyNCDF, dplyr
Suggests: zeallot, testthat, knitr, markdown, rmarkdown
VignetteBuilder: knitr
License: GPL-3
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.1
Config/testthat/edition: 3
NeedsCompilation: yes
Packaged: 2026-05-27 10:28:03 UTC; vagudets
Author: Nuria Perez-Zanon [aut] (ORCID:
    <https://orcid.org/0000-0001-8568-3071>),
  Louis-Philippe Caron [aut] (ORCID:
    <https://orcid.org/0000-0001-5221-0147>),
  Carmen Alvarez-Castro [aut] (ORCID:
    <https://orcid.org/0000-0002-9958-010X>),
  Lauriane Batte [aut],
  Carlos Delgado [aut],
  Jost von Hardenberg [aut] (ORCID:
    <https://orcid.org/0000-0002-5312-8070>),
  Llorenç LLedo [aut],
  Nicolau Manubens [aut],
  Lluís Palma [aut],
  Eroteida Sanchez-Garcia [aut],
  Bert van Schaeybroeck [aut],
  Veronica Torralba [aut],
  Deborah Verfaillie [aut],
  Eva Rifà [ctb],
  Filippo Cali Quaglia [ctb],
  Maria M. Chaves-Montero [ctb],
  Chihchung Chou [ctb],
  Nicola Cortesi [ctb],
  Susanna Corti [ctb],
  Paolo Davini [ctb],
  Gildas Dayon [ctb],
  Marta Dominguez [ctb],
  Federico Fabiano [ctb],
  Ignazio Giuntoli [ctb],
  Raul Marcos [ctb],
  Paola Marson [ctb],
  Niti Mishra [ctb],
  Jesus Peña [ctb],
  Francesc Roura-Adserias [ctb],
  Silvia Terzago [ctb],
  Danila Volpi [ctb],
  An-Chi Ho [ctb],
  Victoria Agudetse [ctb, cre],
  Theertha Kariyathan [ctb],
  Eren Duzenli [ctb],
  BSC-CNS [cph]
Maintainer: Victoria Agudetse <victoria.agudetse@bsc.es>
Repository: CRAN
Date/Publication: 2026-05-28 12:40:11 UTC
Built: R 4.5.2; x86_64-apple-darwin20; 2026-05-28 16:03:58 UTC; unix
Archs: CSTools.so.dSYM
