# Generated by roxygen2: do not edit by hand

S3method(print,s2dv_cube)
export(AdamontAnalog)
export(AdamontQQCorr)
export(Analogs)
export(AreaWeighted)
export(BEI_EMWeighting)
export(BEI_PDFBest)
export(BEI_ProbsWeighting)
export(BEI_TercilesWeighting)
export(BEI_Weights)
export(BiasCorrection)
export(BindDim)
export(CST_AdamontAnalog)
export(CST_AdamontQQCorr)
export(CST_Analogs)
export(CST_AnalogsPredictors)
export(CST_Anomaly)
export(CST_AreaWeighted)
export(CST_BEI_Weighting)
export(CST_BiasCorrection)
export(CST_BindDim)
export(CST_Calibration)
export(CST_CategoricalEnsCombination)
export(CST_ChangeDimNames)
export(CST_DynBiasCorrection)
export(CST_EnsClustering)
export(CST_InsertDim)
export(CST_Load)
export(CST_MergeDims)
export(CST_MultiEOF)
export(CST_MultiMetric)
export(CST_MultivarRMSE)
export(CST_ProxiesAttractor)
export(CST_QuantileMapping)
export(CST_RFSlope)
export(CST_RFTemp)
export(CST_RFWeights)
export(CST_RainFARM)
export(CST_RegimesAssign)
export(CST_ReorderDims)
export(CST_SaveExp)
export(CST_SplitDim)
export(CST_Start)
export(CST_Subset)
export(CST_Summary)
export(CST_WeatherRegimes)
export(Calibration)
export(CategoricalEnsCombination)
export(DynBiasCorrection)
export(EnsClustering)
export(EvalTrainIndices)
export(MergeDims)
export(MultiEOF)
export(MultiMetric)
export(PDFIndexHind)
export(PlotCombinedMap)
export(PlotForecastPDF)
export(PlotMostLikelyQuantileMap)
export(PlotPDFsOLE)
export(PlotTriangles4Categories)
export(PlotWeeklyClim)
export(Predictability)
export(ProxiesAttractor)
export(QuantileMapping)
export(RFSlope)
export(RFTemp)
export(RF_Weights)
export(RainFARM)
export(RegimesAssign)
export(SaveExp)
export(SplitDim)
export(WeatherRegime)
export(as.s2dv_cube)
export(s2dv_cube)
export(training_analogs)
import(RColorBrewer)
import(abind)
import(easyNCDF)
import(ggplot2)
import(lubridate)
import(multiApply)
import(ncdf4)
import(qmap)
import(rainfarmr)
import(s2dv)
import(scales)
import(startR)
import(stats)
importFrom(ClimProjDiags,SelBox)
importFrom(ClimProjDiags,Subset)
importFrom(RColorBrewer,brewer.pal)
importFrom(abind,abind)
importFrom(data.table,CJ)
importFrom(data.table,data.table)
importFrom(data.table,setkey)
importFrom(dplyr,"%>%")
importFrom(easyVerification,climFairRpss)
importFrom(easyVerification,veriApply)
importFrom(grDevices,adjustcolor)
importFrom(grDevices,bmp)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,dev.cur)
importFrom(grDevices,dev.new)
importFrom(grDevices,dev.off)
importFrom(grDevices,hcl)
importFrom(grDevices,jpeg)
importFrom(grDevices,pdf)
importFrom(grDevices,png)
importFrom(grDevices,postscript)
importFrom(grDevices,svg)
importFrom(grDevices,tiff)
importFrom(graphics,axis)
importFrom(graphics,box)
importFrom(graphics,image)
importFrom(graphics,layout)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,plot.new)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,text)
importFrom(graphics,title)
importFrom(maps,map)
importFrom(plyr,.)
importFrom(plyr,dlply)
importFrom(reshape2,melt)
importFrom(s2dv,ACC)
importFrom(s2dv,Ano_CrossValid)
importFrom(s2dv,Clim)
importFrom(s2dv,ColorBar)
importFrom(s2dv,Corr)
importFrom(s2dv,EOF)
importFrom(s2dv,Eno)
importFrom(s2dv,InsertDim)
importFrom(s2dv,Load)
importFrom(s2dv,MeanDims)
importFrom(s2dv,PlotEquiMap)
importFrom(s2dv,RMS)
importFrom(s2dv,RMSSS)
importFrom(s2dv,Reorder)
importFrom(utils,capture.output)
importFrom(utils,glob2rx)
importFrom(utils,head)
importFrom(utils,read.table)
importFrom(utils,tail)
importFrom(verification,verify)
useDynLib(CSTools)
