
			-----------------------
				Cstools
			-----------------------

	Tools for dealing with Czech texts in Perl. I will be glad
	if anybody suggests to make these methods more general,
	including more languages and/or charsets. Maybe we should put
	these into the Convert:: namespace?

Readme pro distribuci Cstools:

	V tomto balíku jsou moduly, které mohou být užitečné při práci
	s českými (a slovenskými) texty v Perlu.

	Modul Cz::Cstocs:

		Objekt, pomocí něhož je možno konvertovat mezi
		znakovými sadami bez nutnosti vnějšího programu -- buď
		formou objektovou, nebo přímými konverzními funkcemi.
		Jednou ze znakových sad je i sada tex, tedy např. \v{c}.
		
	Program cstocs:

		Tato verze konverzího programu cstocs je založena na
		výše uvedeném modulu. Provádí převody kódování nad
		danými soubory nebo nad standardním vstupem.

	Modul Cz::Sort:

		Implementuje čtyřprůchodové české třídění, nezávislé
		na použitých locales. Exportuje funkce czcmp a czsort,
		které pracují podobně jako perlovské vestavěné cmp a sort.


Readme file for Cstools distribution:

	This package includes modules that are usefull when dealing
	with Czech (and Slovak) texts in Perl.

	Module Cz::Cstocs:

		Implements object for various charset encodings, used
		for the Czech language -- either as objects, or as
		direct conversion functions. One of the charsets is
		tex for things like \v{c}.
	
	Program cstocs:

		This version of popular charset reencoding utility
		uses the above mentioned module to convert text
		between various charsets.

	Module Cz::Sort:

		Sorts according to Czech sorting conventions, regardless
		on locale setting. Exports functions czcmp and czsort
		which can be used in similar way as as Perl's internals
		cmp and sort.

Installation:
	Download the tar.gz, unpack it, change to the Cstools-*
	directory. Then do

		perl Makefile.PL
		make
		make test
		make install

	or you can use CPAN module and just type "install Cz::Cstocs".

Ideas, bug reports:
	Any comments or bug reports concerning this module can be send
	to my e-mail address. Sending message to clpm is OK but send
	a copy to me since I might miss your post. Please provide as
	much information as possible, including version of Perl and
	this module, and mention "Cstocs" in the Subject -- it will
	help me solve the problem faster.

Available:
	http://www.fi.muni.cz/~adelton/perl/ and from your favorite
	CPAN site in the authors/id/JANPAZ/ directory.
	
Copyright: (c) 1997--2000 Jan Pazdziora, adelton@fi.muni.cz. All rights
	reserved. This library is free software; you can redistribute
	it and/or modify it under the same terms as Perl itself.

