# Use case and example scripts

In this document, you will find example scripts of the package. The first ones are use cases of cliimate data assessment. The second ones are example scripts on the use of the 's2dv_cube' object.

1. **Use cases of climate data assesment and downscaling** 
   1. [Bias adjustment for assessment of an extreme event](inst/doc/usecase/UseCase1_WindEvent_March2018.R)  
   2. [Precipitation Downscaling with RainFARM RF 4](inst/doc/usecase/UseCase2_PrecipitationDownscaling_RainFARM_RF4.R)  
   3. [Precipitation Downscaling with RainFARM RF 100](inst/doc/usecase/UseCase2_PrecipitationDownscaling_RainFARM_RF100.R)  
   4. [Seasonal forecasts for a river flow](inst/doc/usecase/UseCase3_data_preparation_SCHEME_model.R)

2. **Examples on how to use 's2dv_cube'**
   1. [Create an 's2dv_cube'](inst/doc/usecase/ex1_create.R)
   2. [Save 's2dv_cube'](inst/doc/usecase/ex2_save.R)
   3. [Modify any 's2dv_cube' dimension](inst/doc/usecase/ex3_modify_dims.R)
   4. [Subset any 's2dv_cube' dimension](inst/doc/usecase/ex4_subset.R)
